Retrieves a theme configuration by name. Falls back to console theme if the requested theme is not found.
Examples
theme <- get_theme("nejm")
cat(theme$name)
#> New England Journal of Medicine
Retrieves a theme configuration by name. Falls back to console theme if the requested theme is not found.
theme <- get_theme("nejm")
cat(theme$name)
#> New England Journal of Medicine