Registers all themes from a bundle in the current session.
Examples
if (FALSE) { # \dontrun{
bundle <- load_theme_bundle("path/to/bundle.rds")
install_themes_from_bundle(bundle)
} # }
Registers all themes from a bundle in the current session.
if (FALSE) { # \dontrun{
bundle <- load_theme_bundle("path/to/bundle.rds")
install_themes_from_bundle(bundle)
} # }