Automatically renders a table1_blueprint object in the appropriate format (HTML, LaTeX, or console) when used as the last expression in an R Markdown or Quarto code chunk.
Value
A knitr::asis_output object.
Automatically renders a table1_blueprint object in the appropriate format (HTML, LaTeX, or console) when used as the last expression in an R Markdown or Quarto code chunk.
A knitr::asis_output object.