Renders the table. In an interactive RStudio session with the Viewer pane available, opens a formatted HTML rendering in the Viewer (gt-style). Otherwise, renders to the console.
Usage
# S3 method for class 'table1_blueprint'
print(x, ...)Renders the table. In an interactive RStudio session with the Viewer pane available, opens a formatted HTML rendering in the Viewer (gt-style). Otherwise, renders to the console.
# S3 method for class 'table1_blueprint'
print(x, ...)